package com.jay.monitor.data.server.store.mysql;

import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.core.model.serializable.MQDataDTO;
import com.jay.monitor.data.server.daos.JayMonitorMqLogMapper;
import com.jay.monitor.data.server.daos.JayMonitorMqMapper;
import com.jay.monitor.data.server.enums.StoreType;
import com.jay.monitor.data.server.models.entity.JayMonitorMq;
import com.jay.monitor.data.server.models.entity.JayMonitorMqLog;
import com.jay.monitor.data.server.store.AbstractStoreProcess;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * @Module 数据存储器
 * @Description Mysql的MQ存储实现
 * @Author liukaixiong
 * @Date 2020/10/29 13:36
 */
@Component
@Lazy
public class MysqlMQStoreProcess extends AbstractStoreProcess<MQDataDTO> {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private JayMonitorMqMapper mqMapper;

    @Autowired
    private JayMonitorMqLogMapper mqLogMapper;

    @Override
    public StoreType storeType() {
        return StoreType.MYSQL;
    }

    @Override
    public MsgTypeEnums msgTypeEnums() {
        return MsgTypeEnums.MQ;
    }

    @Override
    public Object store(MQDataDTO request) throws Exception {
        JayMonitorMq mqData = new JayMonitorMq();
        BeanUtils.copyProperties(request, mqData);
        mqData.setApplicationName(request.getApplicationName());
        mqData.setApplicationIp(request.getIp());
        mqData.setCreatedDay(request.getCreateDate());
        mqData.setCreatedTime(request.getCreateDate());
        mqData.setDataGroupName(request.getGroupName());
        mqData.setDataGroupKey(request.getGroupKeyName());
        mqData.setDataId(request.getDataId());
        mqData.setLogId(request.getLogId());
        // mqData.setInvokeType(request.getInvokeType().name());
        int affectRow = mqMapper.insert(mqData);
        if (affectRow == 1) {
            JayMonitorMqLog mqLog = new JayMonitorMqLog();
            mqLog.setMonitorId(mqData.getId());
            mqLog.setParentLogId(request.getParentLogId());
            mqLog.setRootLogId(request.getRootLogId());
            mqLog.setCreateDate(request.getCreateDate());
            mqLog.setLogId(request.getLogId());
            mqLog.setLogText(request.getJsonContent());
            int logId = mqLogMapper.insert(mqLog);
        }
        return null;
    }

}
