package com.jay.monitor.data.server.store.mysql;

import com.jay.monitor.data.core.enums.MsgTypeEnums;
import com.jay.monitor.data.core.model.serializable.URLDataDTO;
import com.jay.monitor.data.server.daos.JayMonitorUrlLogMapper;
import com.jay.monitor.data.server.daos.JayMonitorUrlMapper;
import com.jay.monitor.data.server.enums.StoreType;
import com.jay.monitor.data.server.models.entity.JayMonitorUrl;
import com.jay.monitor.data.server.models.entity.JayMonitorUrlLog;
import com.jay.monitor.data.server.store.AbstractStoreProcess;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * @Module 执行器
 * @Description Mysql的URL请求类型处理器
 * @Author liukaixiong
 * @Date 2020/10/29 13:36
 */
@Component
@Lazy
public class MysqlUrlStoreProcess extends AbstractStoreProcess<URLDataDTO> {

    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private JayMonitorUrlMapper urlMapper;

    @Autowired
    private JayMonitorUrlLogMapper urlLogMapper;

    @Override
    public StoreType storeType() {
        return StoreType.MYSQL;
    }

    @Override
    public MsgTypeEnums msgTypeEnums() {
        return MsgTypeEnums.URL;
    }

    @Override
    public Object store(URLDataDTO baseDTO) throws Exception {

        URLDataDTO request = (URLDataDTO) baseDTO;
        String url = request.getUrl();
        if (StringUtils.isNotEmpty(request.getUrl())) {
            url = url.replaceAll("//", "/");
        }

        JayMonitorUrl monitorUrl = new JayMonitorUrl();
        BeanUtils.copyProperties(request, monitorUrl);
        monitorUrl.setUrl(url);
        monitorUrl.setApplicationName(request.getApplicationName());
        monitorUrl.setApplicationIp(request.getIp());
        monitorUrl.setCreatedDay(request.getCreateDate());
        monitorUrl.setCreatedTime(request.getCreateDate());
        monitorUrl.setMonitorType(request.getType().name());
        monitorUrl.setDataGroupName(request.getGroupName());
        monitorUrl.setDataGroupKey(request.getGroupName());
        monitorUrl.setDataId(request.getDataId());

        int id = urlMapper.insert(monitorUrl);

        JayMonitorUrlLog urlLog = new JayMonitorUrlLog();
        urlLog.setMonitorId(id);
        urlLog.setCreateDate(request.getCreateDate());
        urlLog.setLogId(request.getLogId());
        urlLog.setLogText(request.getJsonContent());
        urlLog.setMonitorType(request.getType().name());
        int logId = urlLogMapper.insert(urlLog);
        logger.debug(" 接收到客户端传递过来的数据 ... ");
        return null;
    }

}
